@@ -60,7 +60,14 @@ sub new {
     my (%languages, %language_codes);
     my ($main_lang, $main_lang_code);
     foreach my $file (@$files) {
-        my $doc = Text::Amuse->new(file => $file);
+        my %args;
+        if (ref($file)) {
+            %args = $file->text_amuse_constructor;
+        }
+        else {
+            %args = (file => $file);
+        }
+        my $doc = Text::Amuse->new(%args);
         push @docs, $doc;
 
         my $current_lang_code = $doc->language_code;
@@ -200,16 +207,7 @@ sub raw_html_toc {
         my @pieces = $doc->as_splat_html;
         my @toc = $doc->raw_html_toc;
         my $missing = scalar(@pieces) - scalar(@toc);
-        if ($missing > 1 or $missing < 0) {
-            die "This shouldn't happen: missing pieces: $missing";
-        }
-        elsif ($missing == 1) {
-            push @out, {
-                        index => $index++,
-                        level => 2,
-                        string => "start body",
-                       };
-        }
+        die "This shouldn't happen: missing pieces: $missing" if $missing;
         # main loop
         foreach my $entry (@toc) {
             push @out, {
@@ -285,11 +283,21 @@ sub as_latex {
 
 Always returns true
 
+=head2 wants_postamble
+
+Always returns true
+
+=head2 wants_preamble
+
+Always returns true
+
 =cut
 
-sub wants_toc {
-    return 1;
-}
+sub wants_toc       { return 1; }
+
+sub wants_postamble { return 1; }
+
+sub wants_preamble  { return 1; }
 
 =head2 is_deleted
 
